function [out]=get_logo(path,filename)
% This is a function to get the information needed to plot the VIMS logo on
% a matlab figure from the jpg picture logo. This script works with any picture
% file, as long as path and filename are specified.
%
%   path - the directory with the image file in it
%   filename - the filename of the logo/image
%
%   out - what is needed to plot the image with imagesc or equilavent
%
  %   Aaron Bever, 2007


if(nargin~=0)
    diry=path;
    Fname=filename;
else
    diry='/data/users-tmp/abever/3D_POVERTY_BAY/';
    Fname='V_logo.jpg';
end

Fname=[diry Fname];
tmp=Fname(end-2:end);

out=imread(Fname,tmp);
